==> libprotoident-2.0.12.tar.gz: libprotoident-2.0.12/lib/udp/udp_protocols.h <==
/*
 *
 * Copyright (c) 2011-2016 The University of Waikato, Hamilton, New Zealand.
 * All rights reserved.
 *
 * This file is part of libprotoident.
 *
 * This code has been developed by the University of Waikato WAND
 * research group. For further information please see http://www.wand.net.nz/
 *
 * libprotoident is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * libprotoident is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */


#ifndef UDP_PROTOCOLS_H_
#define UDP_PROTOCOLS_H_

#include "proto_manager.h"

void register_360cn(LPIModuleMap *mod_map);
void register_360p2p(LPIModuleMap *mod_map);
void register_aachen_udp(LPIModuleMap *mod_map);
void register_acercloud(LPIModuleMap *mod_map);
void register_akamai(LPIModuleMap *mod_map);
void register_akamai_transfer(LPIModuleMap *mod_map);
void register_amanda(LPIModuleMap *mod_map);
void register_apple_facetime_init(LPIModuleMap *mod_map);
void register_ares_udp(LPIModuleMap *mod_map);
void register_arksurvival(LPIModuleMap *mod_map);
void register_arma_server(LPIModuleMap *mod_map);
void register_arma3_server(LPIModuleMap *mod_map);
void register_avast_secure_dns(LPIModuleMap *mod_map);
void register_backweb(LPIModuleMap *mod_map);
void register_bacnet(LPIModuleMap *mod_map);
void register_baiduyun_p2p(LPIModuleMap *mod_map);
void register_baofeng_udp(LPIModuleMap *mod_map);
void register_battlefield(LPIModuleMap *mod_map);
void register_bjnp(LPIModuleMap *mod_map);
void register_bmdp(LPIModuleMap *mod_map);
void register_btsync_udp(LPIModuleMap *mod_map);
void register_callofduty(LPIModuleMap *mod_map);
void register_canon_mfnp(LPIModuleMap *mod_map);
void register_checkpoint_rdp(LPIModuleMap *mod_map);
void register_chivalry(LPIModuleMap *mod_map);
void register_cirn(LPIModuleMap *mod_map);
void register_cisco_ipsec(LPIModuleMap *mod_map);
void register_cisco_sslvpn(LPIModuleMap *mod_map);
void register_combatarms(LPIModuleMap *mod_map);
void register_combatarms_p2p(LPIModuleMap *mod_map);
void register_crossfire(LPIModuleMap *mod_map);
void register_crossout(LPIModuleMap *mod_map);
void register_csgo(LPIModuleMap *mod_map);
void register_csoriginal(LPIModuleMap *mod_map);
void register_dahua(LPIModuleMap *mod_map);
void register_db2(LPIModuleMap *mod_map);
void register_dcc_udp(LPIModuleMap *mod_map);
void register_demonware(LPIModuleMap *mod_map);
void register_destiny_udp(LPIModuleMap *mod_map);
void register_dhcp(LPIModuleMap *mod_map);
void register_dht_dict(LPIModuleMap *mod_map);
void register_dht_other(LPIModuleMap *mod_map);
void register_diablo2(LPIModuleMap *mod_map);
void register_dianping_udp(LPIModuleMap *mod_map);
void register_dianshijia(LPIModuleMap *mod_map);
void register_directconnect_udp(LPIModuleMap *mod_map);
void register_discord(LPIModuleMap *mod_map);
void register_dns_udp(LPIModuleMap *mod_map);
void register_dota2(LPIModuleMap *mod_map);
void register_doyo(LPIModuleMap *mod_map);
void register_driveshare(LPIModuleMap *mod_map);
void register_dtls(LPIModuleMap *mod_map);
void register_emule_udp(LPIModuleMap *mod_map);
void register_emule_weak_udp(LPIModuleMap *mod_map);
void register_epson(LPIModuleMap *mod_map);
void register_eso(LPIModuleMap *mod_map);
void register_esp_encap(LPIModuleMap *mod_map);
void register_eye_udp(LPIModuleMap *mod_map);
void register_fasp(LPIModuleMap *mod_map);
void register_forticlient_sslvpn(LPIModuleMap *mod_map);
void register_fortinet(LPIModuleMap *mod_map);
void register_foscam(LPIModuleMap *mod_map);
void register_freechal(LPIModuleMap *mod_map);
void register_funshion_udp(LPIModuleMap *mod_map);
void register_gamespy(LPIModuleMap *mod_map);
void register_gangsofspace(LPIModuleMap *mod_map);
void register_garena(LPIModuleMap *mod_map);
void register_gearsofwar(LPIModuleMap *mod_map);
void register_gnutella_udp(LPIModuleMap *mod_map);
void register_gnutella2_udp(LPIModuleMap *mod_map);
void register_gnutella_weak(LPIModuleMap *mod_map);
void register_gotomeeting(LPIModuleMap *mod_map);
void register_gprs_tunnel(LPIModuleMap *mod_map);
void register_gsm(LPIModuleMap *mod_map);
void register_h1z1(LPIModuleMap *mod_map);
void register_halflife(LPIModuleMap *mod_map);
void register_haloonline(LPIModuleMap *mod_map);
void register_hamachi_udp(LPIModuleMap *mod_map);
void register_heroes_generals(LPIModuleMap *mod_map);
void register_hots(LPIModuleMap *mod_map);
void register_icp(LPIModuleMap *mod_map);
void register_imesh_udp(LPIModuleMap *mod_map);
void register_ipmsg(LPIModuleMap *mod_map);
void register_ipv6_udp(LPIModuleMap *mod_map);
void register_isakmp(LPIModuleMap *mod_map);
void register_jedi_academy(LPIModuleMap *mod_map);
void register_jedi_udp(LPIModuleMap *mod_map);
void register_kademlia(LPIModuleMap *mod_map);
void register_kankan(LPIModuleMap *mod_map);
void register_kaspersky_udp(LPIModuleMap *mod_map);
void register_kazaa(LPIModuleMap *mod_map);
void register_kugou(LPIModuleMap *mod_map);
void register_l2tp(LPIModuleMap *mod_map);
void register_lansync_udp(LPIModuleMap *mod_map);
void register_ldap_ad(LPIModuleMap *mod_map);
void register_line_udp(LPIModuleMap *mod_map);
void register_linkproof(LPIModuleMap *mod_map);
void register_lol(LPIModuleMap *mod_map);
void register_mdns(LPIModuleMap *mod_map);
void register_merakicloud(LPIModuleMap *mod_map);
void register_moh(LPIModuleMap *mod_map);
void register_mp2p_udp(LPIModuleMap *mod_map);
void register_msn_cache(LPIModuleMap *mod_map);
void register_msn_video(LPIModuleMap *mod_map);
void register_msoffice_mac(LPIModuleMap *mod_map);
void register_mta(LPIModuleMap *mod_map);
void register_mystery_05(LPIModuleMap *mod_map);
void register_mystery_0660(LPIModuleMap *mod_map);
void register_mystery_0d(LPIModuleMap *mod_map);
void register_mystery_45(LPIModuleMap *mod_map);
void register_mystery_61_72(LPIModuleMap *mod_map);
void register_mystery_8000_udp(LPIModuleMap *mod_map);
void register_mystery_99(LPIModuleMap *mod_map);
void register_mystery_e9(LPIModuleMap *mod_map);
void register_mystery_qq(LPIModuleMap *mod_map);
void register_n2ping(LPIModuleMap *mod_map);
void register_natpmp(LPIModuleMap *mod_map);
void register_netbios_udp(LPIModuleMap *mod_map);
void register_netcat_cctv_udp(LPIModuleMap *mod_map);
void register_netcore_scan(LPIModuleMap *mod_map);
void register_netflow(LPIModuleMap *mod_map);
void register_newerth(LPIModuleMap *mod_map);
void register_nintendo(LPIModuleMap *mod_map);
void register_noction(LPIModuleMap *mod_map);
void register_noe(LPIModuleMap *mod_map);
void register_norton(LPIModuleMap *mod_map);
void register_ntp(LPIModuleMap *mod_map);
void register_ntp_reflect(LPIModuleMap *mod_map);
void register_nwn(LPIModuleMap *mod_map);
void register_opaserv(LPIModuleMap *mod_map);
void register_openvpn_udp(LPIModuleMap *mod_map);
void register_orbit_udp(LPIModuleMap *mod_map);
void register_overwatch(LPIModuleMap *mod_map);
void register_pando_udp(LPIModuleMap *mod_map);
void register_panipani(LPIModuleMap *mod_map);
void register_planetside2(LPIModuleMap *mod_map);
void register_portmap_rpc(LPIModuleMap *mod_map);
void register_pplive(LPIModuleMap *mod_map);
void register_ppstream(LPIModuleMap *mod_map);
void register_probable_gnutella(LPIModuleMap *mod_map);
void register_ps4_remoteplay(LPIModuleMap *mod_map);
void register_psn(LPIModuleMap *mod_map);
void register_punkbuster(LPIModuleMap *mod_map);
void register_pyzor(LPIModuleMap *mod_map);
void register_qq(LPIModuleMap *mod_map);
void register_qqlive(LPIModuleMap *mod_map);
void register_qqpcmgr(LPIModuleMap *mod_map);
void register_quake(LPIModuleMap *mod_map);
void register_quic(LPIModuleMap *mod_map);
void register_radius(LPIModuleMap *mod_map);
void register_ramsey_dash(LPIModuleMap *mod_map);
void register_rdp_udp(LPIModuleMap *mod_map);
void register_real(LPIModuleMap *mod_map);
void register_risingstorm(LPIModuleMap *mod_map);
void register_roblox(LPIModuleMap *mod_map);
void register_robocraft(LPIModuleMap *mod_map);
void register_rtcp(LPIModuleMap *mod_map);
void register_rtmfp(LPIModuleMap *mod_map);
void register_rtp(LPIModuleMap *mod_map);
void register_sanandreas_mp(LPIModuleMap *mod_map);
void register_second_life_udp(LPIModuleMap *mod_map);
void register_serialnumberd(LPIModuleMap *mod_map);
void register_sip_udp(LPIModuleMap *mod_map);
void register_skype(LPIModuleMap *mod_map);
void register_slp(LPIModuleMap *mod_map);
void register_smite(LPIModuleMap *mod_map);
void register_snapvpn(LPIModuleMap *mod_map);
void register_snmp(LPIModuleMap *mod_map);
void register_sopcast(LPIModuleMap *mod_map);
void register_spamfighter(LPIModuleMap *mod_map);
void register_spotify_bcast(LPIModuleMap *mod_map);
void register_sql_worm(LPIModuleMap *mod_map);
void register_ssdp(LPIModuleMap *mod_map);
void register_starcitizen(LPIModuleMap *mod_map);
void register_starcraft(LPIModuleMap *mod_map);
void register_starleaf(LPIModuleMap *mod_map);
void register_steamfriends(LPIModuleMap *mod_map);
void register_steam_inhomebroadcast(LPIModuleMap *mod_map);
void register_steam_localbroadcast(LPIModuleMap *mod_map);
void register_steam_udp(LPIModuleMap *mod_map);
void register_storm_worm(LPIModuleMap *mod_map);
void register_stun(LPIModuleMap *mod_map);
void register_syslog(LPIModuleMap *mod_map);
void register_teamspeak(LPIModuleMap *mod_map);
void register_teamviewer_udp(LPIModuleMap *mod_map);
void register_teredo(LPIModuleMap *mod_map);
void register_tf2(LPIModuleMap *mod_map);
void register_tftp(LPIModuleMap *mod_map);
void register_thecrew(LPIModuleMap *mod_map);
void register_thq(LPIModuleMap *mod_map);
void register_torchlight2(LPIModuleMap *mod_map);
void register_traceroute(LPIModuleMap *mod_map);
void register_tremulous(LPIModuleMap *mod_map);
void register_turbovpn(LPIModuleMap *mod_map);
void register_tvants(LPIModuleMap *mod_map);
void register_ubisoft_games(LPIModuleMap *mod_map);
void register_udp_no_payload(LPIModuleMap *mod_map);
void register_umeye(LPIModuleMap *mod_map);
void register_unreal(LPIModuleMap *mod_map);
void register_ventrilo(LPIModuleMap *mod_map);
void register_viber_udp(LPIModuleMap *mod_map);
void register_vivox(LPIModuleMap *mod_map);
void register_vpnmaster(LPIModuleMap *mod_map);
void register_vpnrobot_udp(LPIModuleMap *mod_map);
void register_vxworks_exploit(LPIModuleMap *mod_map);
void register_warthunder(LPIModuleMap *mod_map);
void register_webex(LPIModuleMap *mod_map);
void register_wechat_udp(LPIModuleMap *mod_map);
void register_winmessage(LPIModuleMap *mod_map);
void register_wolfet(LPIModuleMap *mod_map);
void register_worm_22105(LPIModuleMap *mod_map);
void register_xfire_p2p(LPIModuleMap *mod_map);
void register_xlsp(LPIModuleMap *mod_map);
void register_xunlei_jsq(LPIModuleMap *mod_map);
void register_xunlei_udp(LPIModuleMap *mod_map);
void register_xunyou(LPIModuleMap *mod_map);
void register_youdao_dict(LPIModuleMap *mod_map);
void register_youku_udp(LPIModuleMap *mod_map);
void register_yy_udp(LPIModuleMap *mod_map);
void register_zeroaccess_udp(LPIModuleMap *mod_map);
void register_zoom(LPIModuleMap *mod_map);
#endif

==> libprotoident-2.0.15_p1.tar.gz: libprotoident-2.0.15-1/lib/udp/udp_protocols.h <==
/*
 *
 * Copyright (c) 2011-2016 The University of Waikato, Hamilton, New Zealand.
 * All rights reserved.
 *
 * This file is part of libprotoident.
 *
 * This code has been developed by the University of Waikato WAND
 * research group. For further information please see http://www.wand.net.nz/
 *
 * libprotoident is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * libprotoident is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */


#ifndef UDP_PROTOCOLS_H_
#define UDP_PROTOCOLS_H_

#include "proto_manager.h"

void register_360cn(LPIModuleMap *mod_map);
void register_360p2p(LPIModuleMap *mod_map);
void register_aachen_udp(LPIModuleMap *mod_map);
void register_acercloud(LPIModuleMap *mod_map);
void register_akamai(LPIModuleMap *mod_map);
void register_akamai_transfer(LPIModuleMap *mod_map);
void register_amanda(LPIModuleMap *mod_map);
void register_apple_facetime_init(LPIModuleMap *mod_map);
void register_ard(LPIModuleMap *mod_map);
void register_ares_udp(LPIModuleMap *mod_map);
void register_arksurvival(LPIModuleMap *mod_map);
void register_arma_server(LPIModuleMap *mod_map);
void register_arma3_server(LPIModuleMap *mod_map);
void register_artcp(LPIModuleMap *mod_map);
void register_assettocorsa(LPIModuleMap *mod_map);
void register_avast_secure_dns(LPIModuleMap *mod_map);
void register_backweb(LPIModuleMap *mod_map);
void register_bacnet(LPIModuleMap *mod_map);
void register_baiduyun_p2p(LPIModuleMap *mod_map);
void register_baofeng_udp(LPIModuleMap *mod_map);
void register_battlefield(LPIModuleMap *mod_map);
void register_bjnp(LPIModuleMap *mod_map);
void register_bmdp(LPIModuleMap *mod_map);
void register_btsync_udp(LPIModuleMap *mod_map);
void register_cacaoweb_udp(LPIModuleMap *mod_map);
void register_callofduty(LPIModuleMap *mod_map);
void register_canon_mfnp(LPIModuleMap *mod_map);
void register_chargen_exploit(LPIModuleMap *mod_map);
void register_checkpoint_rdp(LPIModuleMap *mod_map);
void register_chivalry(LPIModuleMap *mod_map);
void register_ethernetip_udp(LPIModuleMap *mod_map);
void register_cip_io(LPIModuleMap *mod_map);
void register_cirn(LPIModuleMap *mod_map);
void register_cisco_ipsec(LPIModuleMap *mod_map);
void register_cisco_sslvpn(LPIModuleMap *mod_map);
void register_classin_udp(LPIModuleMap *mod_map);
void register_cloudflare_warp(LPIModuleMap *mod_map);
void register_codmobile(LPIModuleMap *mod_map);
void register_combatarms(LPIModuleMap *mod_map);
void register_combatarms_p2p(LPIModuleMap *mod_map);
void register_contract_wars(LPIModuleMap *mod_map);
void register_crossfire(LPIModuleMap *mod_map);
void register_crossout(LPIModuleMap *mod_map);
void register_csgo(LPIModuleMap *mod_map);
void register_csoriginal(LPIModuleMap *mod_map);
void register_dahua(LPIModuleMap *mod_map);
void register_db2(LPIModuleMap *mod_map);
void register_dcc_udp(LPIModuleMap *mod_map);
void register_demonware(LPIModuleMap *mod_map);
void register_destiny_udp(LPIModuleMap *mod_map);
void register_dhcp(LPIModuleMap *mod_map);
void register_dht_dict(LPIModuleMap *mod_map);
void register_dht_other(LPIModuleMap *mod_map);
void register_diablo2(LPIModuleMap *mod_map);
void register_dianping_udp(LPIModuleMap *mod_map);
void register_dianshijia(LPIModuleMap *mod_map);
void register_directconnect_udp(LPIModuleMap *mod_map);
void register_discord(LPIModuleMap *mod_map);
void register_dns_udp(LPIModuleMap *mod_map);
void register_dota2(LPIModuleMap *mod_map);
void register_doyo(LPIModuleMap *mod_map);
void register_driveshare(LPIModuleMap *mod_map);
void register_dtls(LPIModuleMap *mod_map);
void register_emule_udp(LPIModuleMap *mod_map);
void register_emule_weak_udp(LPIModuleMap *mod_map);
void register_epson(LPIModuleMap *mod_map);
void register_eso(LPIModuleMap *mod_map);
void register_esp_encap(LPIModuleMap *mod_map);
void register_eye_udp(LPIModuleMap *mod_map);
void register_fasp(LPIModuleMap *mod_map);
void register_feitwo(LPIModuleMap *mod_map);
void register_forticlient_sslvpn(LPIModuleMap *mod_map);
void register_fortinet(LPIModuleMap *mod_map);
void register_foscam(LPIModuleMap *mod_map);
void register_freechal(LPIModuleMap *mod_map);
void register_freefire(LPIModuleMap *mod_map);
void register_funshion_udp(LPIModuleMap *mod_map);
void register_gamespy(LPIModuleMap *mod_map);
void register_ganglia(LPIModuleMap *mod_map);
void register_gangsofspace(LPIModuleMap *mod_map);
void register_garena(LPIModuleMap *mod_map);
void register_gearsofwar(LPIModuleMap *mod_map);
void register_gnutella_udp(LPIModuleMap *mod_map);
void register_gnutella2_udp(LPIModuleMap *mod_map);
void register_gnutella_weak(LPIModuleMap *mod_map);
void register_gotomeeting(LPIModuleMap *mod_map);
void register_gprs_tunnel(LPIModuleMap *mod_map);
void register_gsm(LPIModuleMap *mod_map);
void register_h1z1(LPIModuleMap *mod_map);
void register_halflife(LPIModuleMap *mod_map);
void register_haloonline(LPIModuleMap *mod_map);
void register_hamachi_udp(LPIModuleMap *mod_map);
void register_heliborne(LPIModuleMap *mod_map);
void register_heroesevolved(LPIModuleMap *mod_map);
void register_heroes_generals(LPIModuleMap *mod_map);
void register_hollachat(LPIModuleMap *mod_map);
void register_hots(LPIModuleMap *mod_map);
void register_icp(LPIModuleMap *mod_map);
void register_imesh_udp(LPIModuleMap *mod_map);
void register_ipmsg(LPIModuleMap *mod_map);
void register_ipv6_udp(LPIModuleMap *mod_map);
void register_isakmp(LPIModuleMap *mod_map);
void register_jedi_academy(LPIModuleMap *mod_map);
void register_jedi_udp(LPIModuleMap *mod_map);
void register_kademlia(LPIModuleMap *mod_map);
void register_kankan(LPIModuleMap *mod_map);
void register_kaspersky_udp(LPIModuleMap *mod_map);
void register_kazaa(LPIModuleMap *mod_map);
void register_kingofglory_udp(LPIModuleMap *mod_map);
void register_kugou(LPIModuleMap *mod_map);
void register_l2tp(LPIModuleMap *mod_map);
void register_lansync_udp(LPIModuleMap *mod_map);
void register_ldap_ad(LPIModuleMap *mod_map);
void register_line_udp(LPIModuleMap *mod_map);
void register_linkproof(LPIModuleMap *mod_map);
void register_loadout(LPIModuleMap *mod_map);
void register_lol(LPIModuleMap *mod_map);
void register_mdns(LPIModuleMap *mod_map);
void register_merakicloud(LPIModuleMap *mod_map);
void register_moh(LPIModuleMap *mod_map);
void register_moonhunters(LPIModuleMap *mod_map);
void register_mp2p_udp(LPIModuleMap *mod_map);
void register_msn_cache(LPIModuleMap *mod_map);
void register_msn_video(LPIModuleMap *mod_map);
void register_msoffice_mac(LPIModuleMap *mod_map);
void register_mta(LPIModuleMap *mod_map);
void register_mystery_05(LPIModuleMap *mod_map);
void register_mystery_0660(LPIModuleMap *mod_map);
void register_mystery_0d(LPIModuleMap *mod_map);
void register_mystery_45(LPIModuleMap *mod_map);
void register_mystery_61_72(LPIModuleMap *mod_map);
void register_mystery_8000_udp(LPIModuleMap *mod_map);
void register_mystery_99(LPIModuleMap *mod_map);
void register_mystery_e9(LPIModuleMap *mod_map);
void register_mystery_qq(LPIModuleMap *mod_map);
void register_n2ping(LPIModuleMap *mod_map);
void register_natpmp(LPIModuleMap *mod_map);
void register_netbios_udp(LPIModuleMap *mod_map);
void register_netcat_cctv_udp(LPIModuleMap *mod_map);
void register_netcore_scan(LPIModuleMap *mod_map);
void register_netflow(LPIModuleMap *mod_map);
void register_newerth(LPIModuleMap *mod_map);
void register_nintendo(LPIModuleMap *mod_map);
void register_noction(LPIModuleMap *mod_map);
void register_noe(LPIModuleMap *mod_map);
void register_norton(LPIModuleMap *mod_map);
void register_ntp(LPIModuleMap *mod_map);
void register_ntp_reflect(LPIModuleMap *mod_map);
void register_nwn(LPIModuleMap *mod_map);
void register_nvidia_gamestream(LPIModuleMap *mod_map);
void register_opaserv(LPIModuleMap *mod_map);
void register_openvpn_udp(LPIModuleMap *mod_map);
void register_orbit_udp(LPIModuleMap *mod_map);
void register_overwatch(LPIModuleMap *mod_map);
void register_paladins(LPIModuleMap *mod_map);
void register_pando_udp(LPIModuleMap *mod_map);
void register_panipani(LPIModuleMap *mod_map);
void register_planetside2(LPIModuleMap *mod_map);
void register_portmap_rpc(LPIModuleMap *mod_map);
void register_pplive(LPIModuleMap *mod_map);
void register_ppstream(LPIModuleMap *mod_map);
void register_probable_gnutella(LPIModuleMap *mod_map);
void register_ps4_remoteplay(LPIModuleMap *mod_map);
void register_psn(LPIModuleMap *mod_map);
void register_punkbuster(LPIModuleMap *mod_map);
void register_pyzor(LPIModuleMap *mod_map);
void register_qq(LPIModuleMap *mod_map);
void register_qqlive(LPIModuleMap *mod_map);
void register_qqpcmgr(LPIModuleMap *mod_map);
void register_qqspeedmobile_udp(LPIModuleMap *mod_map);
void register_quake(LPIModuleMap *mod_map);
void register_quic(LPIModuleMap *mod_map);
void register_qvod_udp(LPIModuleMap *mod_map);
void register_radius(LPIModuleMap *mod_map);
void register_ramsey_dash(LPIModuleMap *mod_map);
void register_rdp_udp(LPIModuleMap *mod_map);
void register_real(LPIModuleMap *mod_map);
void register_risingstorm(LPIModuleMap *mod_map);
void register_raknet(LPIModuleMap *mod_map);
void register_robocraft(LPIModuleMap *mod_map);
void register_rocket_league(LPIModuleMap *mod_map);
void register_rrshare(LPIModuleMap *mod_map);
void register_rtcp(LPIModuleMap *mod_map);
void register_rtmfp(LPIModuleMap *mod_map);
void register_rtp(LPIModuleMap *mod_map);
void register_rulesofsurvival(LPIModuleMap *mod_map);
void register_sanandreas_mp(LPIModuleMap *mod_map);
void register_second_life_udp(LPIModuleMap *mod_map);
void register_serialnumberd(LPIModuleMap *mod_map);
void register_sip_udp(LPIModuleMap *mod_map);
void register_skype(LPIModuleMap *mod_map);
void register_slp(LPIModuleMap *mod_map);
void register_smite(LPIModuleMap *mod_map);
void register_snapvpn(LPIModuleMap *mod_map);
void register_snmp(LPIModuleMap *mod_map);
void register_sopcast(LPIModuleMap *mod_map);
void register_spamfighter(LPIModuleMap *mod_map);
void register_spotify_bcast(LPIModuleMap *mod_map);
void register_sql_worm(LPIModuleMap *mod_map);
void register_ssdp(LPIModuleMap *mod_map);
void register_starcitizen(LPIModuleMap *mod_map);
void register_starcraft(LPIModuleMap *mod_map);
void register_starleaf(LPIModuleMap *mod_map);
void register_steamfriends(LPIModuleMap *mod_map);
void register_steam_inhomebroadcast(LPIModuleMap *mod_map);
void register_steam_localbroadcast(LPIModuleMap *mod_map);
void register_steam_udp(LPIModuleMap *mod_map);
void register_storm_worm(LPIModuleMap *mod_map);
void register_stun(LPIModuleMap *mod_map);
void register_syslog(LPIModuleMap *mod_map);
void register_talesrunner_udp(LPIModuleMap *mod_map);
void register_teamspeak(LPIModuleMap *mod_map);
void register_teamviewer_udp(LPIModuleMap *mod_map);
void register_teredo(LPIModuleMap *mod_map);
void register_tf2(LPIModuleMap *mod_map);
void register_tftp(LPIModuleMap *mod_map);
void register_thecrew(LPIModuleMap *mod_map);
void register_thq(LPIModuleMap *mod_map);
void register_torchlight2(LPIModuleMap *mod_map);
void register_tox(LPIModuleMap *mod_map);
void register_traceroute(LPIModuleMap *mod_map);
void register_tremulous(LPIModuleMap *mod_map);
void register_turbovpn(LPIModuleMap *mod_map);
void register_tvants(LPIModuleMap *mod_map);
void register_ubisoft_games(LPIModuleMap *mod_map);
void register_udp_no_payload(LPIModuleMap *mod_map);
void register_umeye(LPIModuleMap *mod_map);
void register_unreal(LPIModuleMap *mod_map);
void register_ventrilo(LPIModuleMap *mod_map);
void register_viber_udp(LPIModuleMap *mod_map);
void register_vivox(LPIModuleMap *mod_map);
void register_vpnmaster(LPIModuleMap *mod_map);
void register_vpnrobot_udp(LPIModuleMap *mod_map);
void register_vxworks_exploit(LPIModuleMap *mod_map);
void register_warthunder(LPIModuleMap *mod_map);
void register_webex(LPIModuleMap *mod_map);
void register_wechat_udp(LPIModuleMap *mod_map);
void register_winmessage(LPIModuleMap *mod_map);
void register_wireguard(LPIModuleMap *mod_map);
void register_wolfet(LPIModuleMap *mod_map);
void register_worm_22105(LPIModuleMap *mod_map);
void register_xfire_p2p(LPIModuleMap *mod_map);
void register_xlsp(LPIModuleMap *mod_map);
void register_xunlei_jsq(LPIModuleMap *mod_map);
void register_xunlei_udp(LPIModuleMap *mod_map);
void register_xunyou(LPIModuleMap *mod_map);
void register_youdao_dict(LPIModuleMap *mod_map);
void register_youku_udp(LPIModuleMap *mod_map);
void register_yuanfudao(LPIModuleMap *mod_map);
void register_yy_udp(LPIModuleMap *mod_map);
void register_zalo_call(LPIModuleMap *mod_map);
void register_zeroaccess_udp(LPIModuleMap *mod_map);
void register_zoom(LPIModuleMap *mod_map);
#endif
